<template>
  <div class="bbsl-common-page"
       @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam"
               :inline="true">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="测站名称">
              <el-input clearable
                        size="mini"
                        placeholder="请输入测站名称"
                        v-model="queryParam.params.stnm"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="测站类型">
              <el-select size="mini"
                         v-model="queryParam.params.sttp"
                         clearable
                         placeholder="请选择测站类型">
                <el-option v-for="item in sttps"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="测站应用分类">
              <el-select @change="changeResType"
                         size="mini"
                         v-model="queryParam.params.appType"
                         clearable
                         placeholder="请选择测站应用分类">
                <el-option v-for="item in appTypes"
                           :key="item.id"
                           :label="item.name"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item>
              <el-button type="primary"
                         icon="el-icon-search"
                         size="mini"
                         @click="onClickSearch">搜索</el-button>
              <el-button icon="el-icon-refresh"
                         size="mini"
                         @click="resetQuery">重置</el-button>
              <el-button type="text"
                         @click.stop="openMore">更多
                <i :class="
                      showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'
                    "></i>
              </el-button>
            </el-form-item>
          </el-col>
        </el-row>
        <div class="bbsl-search-more"
             style="width:350px"
             v-if="showMore">
          <el-row>
            <el-form-item label="行政区划">
              <el-cascader size="mini"
                           filterable
                           :show-all-levels="false"
                           :options="basAdNames"
                           v-model="queryParam.params.addvcd"
                           :props="{value: 'code', label: 'name', children: 'children'}"
                           @change="onhouChange"
                           placeholder="请选择所属行政区划"
                           clearable></el-cascader>
            </el-form-item>
          </el-row>
        </div>
      </el-form>
    </div>
    <div class="bbsl-table-content"
         ref="contentPanel">
      <div class="bbsl-btn-content"
           ref="btnPanel">
        <el-button size="mini"
                   icon="el-icon-plus"
                   type="primary"
                   @click="openFormDiao">新增</el-button>
        <el-button :disabled="!multipleSelection.length"
                   size="mini"
                   icon="el-icon-delete"
                   type="danger"
                   @click="deleteSelect">删除</el-button>
      </div>
      <el-table stripe
                size="mini"
                :height="tableMaxHeight"
                @row-dblclick="handleDbClick"
                :style="{width: '100%'}"
                ref="multipleSelection"
                v-loading="loading"
                border
                :data="tableData"
                :row-key="getRowKey"
                @selection-change="handleSelectionChange"
                :header-cell-style="{'text-align': 'center'}"
                :cell-style="{'text-align': 'center'}">
        <el-table-column type="selection"
                         width="55"
                         :reserve-selection="true"></el-table-column>
        <el-table-column type="index"
                         width="55"
                         label="序号"></el-table-column>
        <el-table-column min-width="100"
                         sortable
                         prop="stcd"
                         label="测站编码"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="120"
                         sortable
                         prop="stnm"
                         label="测站名称"
                         show-overflow-tooltip></el-table-column>

        <el-table-column min-width="100"
                         sortable
                         prop="sttp"
                         label="测站类型"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="100"
                         sortable
                         prop="appType"
                         label="测站应用分类"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="120"
                         sortable
                         prop="areaName"
                         label="所在行政区划"
                         show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="180"
                         sortable
                         prop="stlc"
                         label=" 安装详细地址"
                         show-overflow-tooltip></el-table-column>
        <el-table-column min-width="80"
                         sortable
                         prop="usfl"
                         label="在线状态"
                         show-overflow-tooltip>
          <template slot-scope="scope">
            <span :style="{
                color:
                  scope.row.wkcn === 1 || scope.row.wkcn === '1'
                    ? 'red'
                    : '#09ef09'
              }"
                  v-if="scope.row.usfl === '1' || scope.row.usfl === 1">正常</span>
            <span :style="{
                color:
                  scope.row.wkcn === 0 || scope.row.wkcn === '0'
                    ? '#09ef09'
                    : 'red'
              }"
                  v-if="scope.row.usfl === '0' || scope.row.usfl === 0">异常</span>
          </template>
        </el-table-column>

      </el-table>
      <el-pagination ref="paginationPanel"
                     align="right"
                     class="bbsl-pagination"
                     background
                     @size-change="handleSizeChange"
                     @current-change="handleCurrentChange"
                     :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30, 40, 50]"
                     :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper"
                     :total="total"></el-pagination>
    </div>
    <form-dialog v-if="showFormDia"
                 @closeFormDiao="closeFormDiao"
                 @refList="getDateList"
                 :showFormDia="showFormDia"
                 :title="title"
                 :pId="pId"></form-dialog>
  </div>
</template>
<script>
import FormDialog from './components/syqForm-dialog.vue'
import syqStation from '@/api/stManager/syqStation'
import req from '@/request.js'
import { TableMixin } from '@/mixins/tableMixin'
export default {
  name: 'syqStation',
  components: {
    FormDialog,
  },
  mixins: [TableMixin],
  data () {
    return {
      resTypes: [], //水库类型
      loading: false,
      multipleSelection: [], // 复选框
      queryParam: {
        pageBean: {
          pageSize: 20,
          page: 1,
        },
        params: {
          rsnm: null, //测站名称
          sttp: null,//测站类型
          appType: null, //测站应用分类
          addvcd: null, //行政区
		  isSyqPage:'true'
        },
      },
      total: 0,
      title: '',
      showFormDia: false,
      tableData: [],
      pId: '',
      errMessage: '',
      errorFileUrl: '',
      basAdNames: [], //行政区
      lookDetailDia: false, // 详情弹层
      codes: { codes: 'gkglbm' },
      sttps: [], //测站类型
      appTypes: [],//测站应用分类
    }
  },
  created () {
    this.getDateList();
    this.getSysDict();
    // 行政区查询
    syqStation.getbasAdName({}, (res) => {
      this.basAdNames = res.value
    })
  },
  methods: {
    openMore () {
      this.showMore = !this.showMore
    },
    //获取字典数据
    getSysDict () {
      let portal = window.context.portal
      return new Promise((resolve, reject) => {
        req.post(portal + '/sys/sysDictionary/v1/queryAllDictItems').then(
          (response) => {
            resolve(response.data)
            let a=response.data.czzl
            this.sttps=a.slice(0,-1)
            this.appTypes = response.data.czyyfl;
            this.getDateList()
          },
          (error) => {
            reject(error)
          }
        )
      })
    },
    changeResType (val) {
      if (val) {
        this.queryParam.params.appType = val;
      } else {
        this.queryParam.params.appType = null
      }
    },
    onhouChange (val) {
      if (val) {
        this.queryParam.params.addvcd = val.pop()
      } else {
        this.queryParam.params.addvcd = null
      }
    },
    getDateList () {
      this.loading = true;
      this.tableData = [];
      //列表展示转换
      syqStation.ListGet(this.queryParam, (res) => {
        this.tableData = res.value.rows;
        this.total = res.value.total;
        this.tableData.forEach(e => {
          this.sttps.forEach(i => {
            if (i.value === e.sttp) {
              e.sttp = i.name;
            }
            this.appTypes.forEach(j => {
              if (j.value === e.appType) {
                e.appType = j.name;
              }
            })
          })
        })
        this.loading = false;
        this.$set(this.tableData)
      })
    },
    openFormDiao () {
      this.title = '新增';
      this.showFormDia = true;
    },
    closeFormDiao () {
      this.showFormDia = false;
      this.getDateList();
    },
    handleSizeChange (val) {
      this.queryParam.pageBean.pageSize = val
      this.getDateList()
    },
    handleCurrentChange (val) {
      this.queryParam.pageBean.page = val
      this.getDateList()
    },
    //修改
    handleUpdate (row) {
      this.title = '修改';
      this.pId = row.id;
      this.showFormDia = true;
    },
    handleSelectionChange (val) {
      this.multipleSelection = val.map((item) => {
        return item.id;
      })
    },
    // // 指定一个key标识这一行的数据
    getRowKey (row) {
      return row.id;
    },
    // // 批量删除
    deleteSelect () {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          syqStation
            .remove(this.multipleSelection, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                // this.multipleSelection = [];
                this.$refs.multipleSelection.clearSelection()
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    /** 删除按钮操作 */
    handleDelete (row) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          syqStation.remove(row.id, (res) => {
            if (res.state) {
              this.$notify({
                type: 'success',
                message: '删除成功',
                duration: 2000,
                // offset: 80
              })
              this.queryParam.pageBean.page = 1
              this.getDateList()
            }
          })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => { })
    },
    // // 点击查询
    onClickSearch () {
      //     this.queryParam.basArea=this.queryParam.basArea;
      //   if (this.queryParam.basArea) {
      //     this.queryParam.basArea = this.queryParam.basArea + 'km2'
      //   } else {
      //     this.queryParam.basArea = null
      //   }
      this.queryParam.pageBean.page = 1
      this.getDateList()
    },
    // 重置
    resetQuery () {
      this.queryParam.params = {}
      this.onClickSearch()
    },
  },
}
</script>
<style lang="scss" scoped>
.btn-content {
  display: flex;
}
.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}
.el-select-dropdown__item {
  color: #9a9a9a !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}
.btn-content :first-child {
  margin: 0 0 0 0 !important;
}
// ::v-deep .el-table__body-wrapper::-webkit-scrollbar {
//   width: 6px;
//   height: 15px;
// }
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}
::-webkit-scrollbar {
  background: #fff !important;
}
.v-modal {
  z-index: 11 !important;
}
.bbsl-pagination {
  bottom: 10px !important;
}
</style>
